@@ -211,6 +211,25 @@ sp_callgraph_view_unload (SpCallgraphView *self)
   g_queue_clear (priv->history);
   g_clear_object (&priv->profile);
   priv->profile_size = 0;
+
+  gtk_tree_view_set_model (priv->callers_view, NULL);
+  gtk_tree_view_set_model (priv->functions_view, NULL);
+  gtk_tree_view_set_model (priv->descendants_view, NULL);
+}
+
+/**
+ * sp_callgraph_view_get_profile:
+ *
+ * Returns: (transfer none): An #SpCallgraphProfile.
+ */
+SpCallgraphProfile *
+sp_callgraph_view_get_profile (SpCallgraphView *self)
+{
+  SpCallgraphViewPrivate *priv = sp_callgraph_view_get_instance_private (self);
+
+  g_return_val_if_fail (SP_IS_CALLGRAPH_VIEW (self), NULL);
+
+  return priv->profile;
 }
 
 void
@@ -492,6 +511,9 @@ sp_callgraph_view_set_node (SpCallgraphView *self,
   g_assert (SP_IS_CALLGRAPH_VIEW (self));
   g_assert (node != NULL);
 
+  if (priv->profile == NULL)
+    return;
+
   model = gtk_tree_view_get_model (priv->functions_view);
 
   if (gtk_tree_model_get_iter_first (model, &iter))
@@ -586,6 +608,9 @@ sp_callgraph_view_tag_data_func (GtkTreeViewColumn *column,
   StackNode *node = NULL;
   const gchar *str = NULL;
 
+  if (priv->profile == NULL)
+    return;
+
   gtk_tree_model_get (model, iter, COLUMN_POINTER, &node, -1);
 
   if (node && node->data)
